"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = buildRtdbCommand;

var _isBoolean2 = _interopRequireDefault(require("lodash/isBoolean"));

var _isObject2 = _interopRequireDefault(require("lodash/isObject"));

var _utils = require("./utils");

var _constants = require("./constants");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function buildRtdbCommand(Cypress, action, actionPath, fixturePath, opts = {}) {
  const options = (0, _isObject2.default)(fixturePath) ? fixturePath : opts;
  const _options$args = options.args,
        args = _options$args === void 0 ? [] : _options$args;
  const argsWithDefaults = (0, _utils.addDefaultArgs)(Cypress, args);
  const argsStr = (0, _utils.getArgsString)(argsWithDefaults);

  switch (action) {
    case 'delete':
      return `${_constants.FIREBASE_TOOLS_BASE_COMMAND} database:${action} ${actionPath}${argsStr}`;

    case 'get':
      {
        const getDataArgsWithDefaults = (0, _utils.addDefaultArgs)(Cypress, args, {
          disableYes: true
        });

        if (options.limitToLast) {
          const lastCount = (0, _isBoolean2.default)(options.limitToLast) ? 1 : options.limitToLast;

          if (!options.orderByChild) {
            getDataArgsWithDefaults.push(`--order-by-key --limit-to-last ${lastCount}`);
          } else {
            getDataArgsWithDefaults.push(`--order-by-child ${options.orderByChild} --limit-to-last ${lastCount}`);
          }
        }

        const getDataArgsStr = (0, _utils.getArgsString)(getDataArgsWithDefaults);
        return `${_constants.FIREBASE_TOOLS_BASE_COMMAND} database:${action} /${actionPath}${getDataArgsStr}`;
      }

    default:
      {
        return `${_constants.FIREBASE_TOOLS_BASE_COMMAND} database:${action} /${actionPath} ${fixturePath}${argsStr}`;
      }
  }
}

module.exports = exports.default;