"use strict";Object.defineProperty(exports,"__esModule",{value:true});exports.readJsonFile=readJsonFile;exports.getEnvPrefix=getEnvPrefix;exports.getCypressFolderPath=getCypressFolderPath;exports.envVarBasedOnCIEnv=envVarBasedOnCIEnv;exports.getServiceAccount=getServiceAccount;exports.slashPathToFirestoreRef=slashPathToFirestoreRef;exports.getArgsString=getArgsString;exports.addDefaultArgs=addDefaultArgs;exports.isPromise=isPromise;exports.runCommand=runCommand;exports.shellescape=shellescape;var _dropRight2=_interopRequireDefault(require("lodash/dropRight"));var _get2=_interopRequireDefault(require("lodash/get"));var _isArray2=_interopRequireDefault(require("lodash/isArray"));var _compact2=_interopRequireDefault(require("lodash/compact"));var _drop2=_interopRequireDefault(require("lodash/drop"));var _isString2=_interopRequireDefault(require("lodash/isString"));var _path=_interopRequireDefault(require("path"));var _chalk=_interopRequireDefault(require("chalk"));var _fs=_interopRequireDefault(require("fs"));var _stream=_interopRequireDefault(require("stream"));var _filePaths=require("./filePaths");var _constants=require("./constants");var _logger=require("./logger");function _interopRequireDefault(obj){return obj&&obj.__esModule?obj:{default:obj}}const _require=require("child_process"),spawn=_require.spawn;function readJsonFile(filePath){if(!_fs.default.existsSync(filePath)){return{}}try{return JSON.parse(_fs.default.readFileSync(filePath,"utf8"))}catch(err){(0,_logger.error)(`Unable to parse ${_chalk.default.cyan(filePath.replace(_constants.DEFAULT_BASE_PATH,""))} - JSON is most likley not valid`);return{}}}function getEnvironmentSlug(){return process.env.CI_ENVIRONMENT_SLUG||"stage"}function getEnvPrefix(envName){const envSlug=envName||getEnvironmentSlug();return`${envSlug.toUpperCase()}_`}function getServiceAccountPath(envName=""){const withPrefix=_path.default.join(_constants.DEFAULT_BASE_PATH,`serviceAccount-${envName}.json`);if(_fs.default.existsSync(withPrefix)){return withPrefix}return _path.default.join(_constants.DEFAULT_BASE_PATH,"serviceAccount.json")}function getCypressFolderPath(){const cypressConfig=readJsonFile(_filePaths.TEST_CONFIG_FILE_PATH);const integrationTestsFolderPath=(0,_get2.default)(cypressConfig,"integrationFolder");return integrationTestsFolderPath?(0,_dropRight2.default)(integrationTestsFolderPath.split("/")).join("/"):_constants.DEFAULT_TEST_FOLDER_PATH}function envVarBasedOnCIEnv(varNameRoot,envName){const prefix=getEnvPrefix(envName);const combined=`${prefix}${varNameRoot}`;if(_fs.default.existsSync(_filePaths.LOCAL_CONFIG_FILE_PATH)){const configObj=readJsonFile(_filePaths.LOCAL_CONFIG_FILE_PATH);return configObj[combined]||configObj[varNameRoot]}if(_fs.default.existsSync(_filePaths.TEST_ENV_FILE_PATH)){const configObj=readJsonFile(_filePaths.TEST_ENV_FILE_PATH);return configObj[combined]||configObj[varNameRoot]}return process.env[combined]||process.env[varNameRoot]}function getParsedEnvVar(varNameRoot){const val=envVarBasedOnCIEnv(varNameRoot);const prefix=getEnvPrefix();const combinedVar=`${prefix}${varNameRoot}`;if(!val){(0,_logger.error)(`${_chalk.default.cyan(combinedVar)} not found, make sure it is set within environment variables.`)}try{if((0,_isString2.default)(val)){return JSON.parse(val)}return val}catch(err){(0,_logger.error)(`Error parsing ${combinedVar}`);return val}}function getServiceAccount(envSlug){const serviceAccountPath=getServiceAccountPath(envSlug);if(_fs.default.existsSync(serviceAccountPath)){return readJsonFile(serviceAccountPath)}(0,_logger.info)(`Service account does not exist at path: "${_chalk.default.cyan(serviceAccountPath.replace(`${_constants.DEFAULT_BASE_PATH}/`,""))}" falling back to environment variables...`);return{type:"service_account",project_id:envVarBasedOnCIEnv("FIREBASE_PROJECT_ID"),private_key_id:envVarBasedOnCIEnv("FIREBASE_PRIVATE_KEY_ID"),private_key:getParsedEnvVar("FIREBASE_PRIVATE_KEY"),client_email:envVarBasedOnCIEnv("FIREBASE_CLIENT_EMAIL"),client_id:envVarBasedOnCIEnv("FIREBASE_CLIENT_ID"),auth_uri:"https://accounts.google.com/o/oauth2/auth",token_uri:"https://accounts.google.com/o/oauth2/token",auth_provider_x509_cert_url:"https://www.googleapis.com/oauth2/v1/certs",client_x509_cert_url:envVarBasedOnCIEnv("FIREBASE_CERT_URL")}}function slashPathToFirestoreRef(firestoreInstance,slashPath,options={}){let ref=firestoreInstance;const srcPathArr=slashPath.split("/");srcPathArr.forEach(pathSegment=>{if(ref.collection){ref=ref.collection(pathSegment)}else if(ref.doc){ref=ref.doc(pathSegment)}else{throw new Error(`Invalid slash path: ${slashPath}`)}});if(options.limit&&typeof ref.limit==="function"){ref=ref.limit(options.limit)}return ref}function getArgsString(args){return args&&args.length?` ${args.join(" ")}`:""}function addDefaultArgs(Cypress,args,opts={}){const _opts$disableYes=opts.disableYes,disableYes=_opts$disableYes===void 0?false:_opts$disableYes;const newArgs=[...args];const projectId=Cypress.env("firebaseProjectId")||Cypress.env("FIREBASE_PROJECT_ID")||Cypress.env("STAGE_FIREBASE_PROJECT_ID");if(!newArgs.includes("-P")||!newArgs.includes(projectId)){newArgs.push("-P");newArgs.push(projectId)}if(!disableYes&&!newArgs.includes(_constants.FIREBASE_TOOLS_YES_ARGUMENT)){newArgs.push(_constants.FIREBASE_TOOLS_YES_ARGUMENT)}return newArgs}process.env.FORCE_COLOR=true;function isPromise(valToCheck){return valToCheck&&typeof valToCheck.then==="function"}function runCommand({beforeMsg,successMsg,command,errorMsg,args,pipeOutput=true}){if(beforeMsg)(0,_logger.info)(beforeMsg);return new Promise((resolve,reject)=>{const child=spawn((0,_isArray2.default)(command)?command[0]:command.split(" ")[0],args||(0,_compact2.default)((0,_drop2.default)(command.split(" "))));let output;let error;const customStream=new _stream.default.Writable;const customErrorStream=new _stream.default.Writable;customStream._write=(data,...argv)=>{output+=data;if(pipeOutput){process.stdout._write(data,...argv)}};customErrorStream._write=(data,...argv)=>{error+=data;if(pipeOutput){process.stderr._write(data,...argv)}};child.stdout.pipe(customStream);child.stderr.pipe(customErrorStream);child.on("exit",code=>{if(code!==0){if(output&&output.indexOf("npm WARN")!==-1){return resolve(successMsg||output)}if(errorMsg){console.log(errorMsg)}reject(error||output)}else{if(successMsg)(0,_logger.info)(successMsg);if(output&&output.indexOf("undefined")===0){resolve(successMsg||output.replace("undefined",""))}else{console.log("output: ",output);resolve(successMsg||output)}}})})}function shellescape(a){const ret=[];a.forEach(s=>{if(/[^A-Za-z0-9_/:=-]/.test(s)){s=`'${s.replace(/'/g,"'\\''")}'`;s=s.replace(/^(?:'')+/g,"").replace(/\\'''/g,"\\'")}ret.push(s)});return ret.join(" ")}